summaryrefslogtreecommitdiffstats
path: root/Modules/FindLATEX.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'Modules/FindLATEX.cmake')
-rw-r--r--Modules/FindLATEX.cmake12
1 files changed, 9 insertions, 3 deletions
diff --git a/Modules/FindLATEX.cmake b/Modules/FindLATEX.cmake
index e353d38..a935f00 100644
--- a/Modules/FindLATEX.cmake
+++ b/Modules/FindLATEX.cmake
@@ -4,8 +4,9 @@
#
# Find Latex
#
# This module finds if Latex is installed and determines where the
# executables are. This code sets the following variables:
#
# ::
#
@@ -18,7 +19,7 @@
# LATEX2HTML_CONVERTER: path to the LaTeX2Html converter
#=============================================================================
-# Copyright 2002-2009 Kitware, Inc.
+# Copyright 2002-2014 Kitware, Inc.
#
# Distributed under the OSI-approved BSD License (the "License");
# see accompanying file Copyright.txt for details.
@@ -131,3 +132,8 @@ mark_as_advanced(
PS2PDF_CONVERTER
LATEX2HTML_CONVERTER
)
+
+include(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
+find_package_handle_standard_args(Latex
+ REQUIRED_VARS LATEX_COMPILER
+)
@@ -4,8 +4,9 @@
# Find Latex
#
-# This module finds if Latex is installed and determines where the
-# executables are. This code sets the following variables:
+# This module finds an installed Latex and determines the location
+# of the compiler. Additionally the module looks for Latex-related
+# software like BibTeX. This code sets the following variables:
#
# ::